# rsocket-py

Python implementation of [RSocket](http://rsocket.io)

# Documentation

Work in progress.

Also see the examples:  [RSocket Requester](./examples/client.py) and [RSocket Responder](./examples/server.py)

# Build Status

<a href='https://travis-ci.org/rsocket/rsocket-py/builds'>
    <img src='https://travis-ci.org/rsocket/rsocket-py.svg?branch=master'>
</a>
